@@ -16,22 +16,25 @@ pkgname <- function(env = parent.frame()) {
 
 `%||%` <- function(lhs, rhs) if (is.null(lhs)) rhs else lhs
 
-vlapply <- function(..., FUN.VALUE = logical(1L)) {  # nolint object_name_linter
+vlapply <- function(..., FUN.VALUE = logical(1L)) { # nolint object_name_linter
   vapply(..., FUN.VALUE = FUN.VALUE)
 }
 
-vcapply <- function(..., FUN.VALUE = character(1L)) {  # nolint object_name_linter
+vcapply <- function(..., FUN.VALUE = character(1L)) { # nolint object_name_linter
   vapply(..., FUN.VALUE = FUN.VALUE)
 }
 
+#' @keywords internal
 as_env <- function(x) {
   UseMethod("as_env")
 }
 
+#' @keywords internal
 as_env.character <- function(x) {
   getNamespace(x)
 }
 
+#' @keywords internal
 as_env.environment <- function(x) {
   x
 }
@@ -44,20 +47,27 @@ list_is_all_unnamed <- function(x) {
   is.null(names(x)) || all(names(x) == "")
 }
 
+#' @keywords internal
 raise <- function(x, ...) {
   UseMethod("raise")
 }
 
+#' @keywords internal
 raise.character <- function(x, ...) {
   x <- switch(x,
-    "print" = , "info" = , "message" = message,
-    "warn" = , "warning" = warning,
-    "error" = , "stop" = stop
+    "print" = ,
+    "info" = ,
+    "message" = message,
+    "warn" = ,
+    "warning" = warning,
+    "error" = ,
+    "stop" = stop
   )
 
   raise.function(x, ...)
 }
 
+#' @keywords internal
 raise.function <- function(x, msg, ...) {
   args <- list(msg, ...)
 
